@@ -14,7 +14,7 @@ use English qw/ -no_match_vars /;
 use File::chdir;
 use Getopt::Alt;
 
-our $VERSION = version->new('0.3.1');
+our $VERSION = version->new('0.3.2');
 
 requires 'repos';
 requires 'verbose';
@@ -33,7 +33,8 @@ sub status {
 
     local $CWD = $name;
     $cmd = join ' ', 'git', 'status', map { $self->shell_quote } @ARGV;
-    my $out = `$cmd`;
+
+    my $out = `$cmd 2>&1`;
 
     return $out if $self->verbose;
 
@@ -52,7 +53,7 @@ Group::Git::Cmd::Status - Runs git status on a git project
 
 =head1 VERSION
 
-This documentation refers to Group::Git::Cmd::Status version 0.3.1.
+This documentation refers to Group::Git::Cmd::Status version 0.3.2.
 
 
 =head1 SYNOPSIS
