@@ -15,7 +15,7 @@ use File::chdir;
 use Getopt::Alt;
 use YAML::Syck qw/LoadFile DumpFile/;
 
-our $VERSION = version->new('0.3.1');
+our $VERSION = version->new('0.3.2');
 
 requires 'repos';
 requires 'verbose';
@@ -105,10 +105,6 @@ sub watch {
     return;
 }
 
-sub watch_end {
-    return "Do you have any repositories?\n";
-}
-
 1;
 
 __END__
@@ -119,7 +115,7 @@ Group::Git::Cmd::Watch - Watch for changes in repositories and run a command
 
 =head1 VERSION
 
-This documentation refers to Group::Git::Cmd::Watch version 0.3.1.
+This documentation refers to Group::Git::Cmd::Watch version 0.3.2.
 
 
 =head1 SYNOPSIS
@@ -155,6 +151,10 @@ Runs git watch on each directory if the watch message includes:
 The watch is suppressed to keep the output clean. This can be overridden
 if verbose is set.
 
+=item C<watch_start ()>
+
+Process the command line arguments for watch
+
 =back
 
 =head1 DIAGNOSTICS
